@@ -24,8 +24,8 @@
 #include "image_luma.h"
 #include "soft_focus.h"
 
-#include <image_filters.h>
-#include <image_transitions.h>
+#include <kino/image_filters.h>
+#include <kino/image_transitions.h>
 
 extern "C"
 {
